@@ -42,6 +42,8 @@
 #define EEL_STANDARD_CLOSE_WINDOW_CONTROL_KEY 	'w'
 
 /* GtkButton */
+GtkWidget*            eel_gtk_button_new_with_stock_icon              (const gchar	    *label,
+								       const gchar	    *stock_id);
 void                  eel_gtk_button_set_padding                      (GtkButton            *button,
 								       int                   pad_amount);
 
@@ -112,7 +114,8 @@ void                  eel_gtk_window_set_initial_geometry             (GtkWindow
 void                  eel_gtk_window_set_initial_geometry_from_string (GtkWindow            *window,
 								       const char           *geometry_string,
 								       guint                 minimum_width,
-								       guint                 minimum_height);
+								       guint                 minimum_height,
+								       gboolean		     ignore_position);
 void                  eel_gtk_window_set_up_close_accelerator         (GtkWindow            *window);
 gboolean              eel_gtk_window_event_is_close_accelerator       (GtkWindow            *window,
 								       GdkEventKey          *event);
@@ -136,7 +139,10 @@ void                  eel_gtk_menu_set_item_visibility                (GtkMenu
 void                  eel_gtk_label_make_bold                         (GtkLabel             *label);
 void                  eel_gtk_label_set_scale                         (GtkLabel             *label,
 								       double                scale_factor);
-
+void                  eel_gtk_label_set_drop_shadow_color             (GtkLabel             *label,
+								       guint32               color);
+void                  eel_gtk_label_set_drop_shadow_offset            (GtkLabel             *label,
+								       gint                  offset); 
 /* GtkAdjustment */
 void                  eel_gtk_adjustment_set_value                    (GtkAdjustment        *adjustment,
 								       float                 value);
@@ -149,6 +155,8 @@ PangoContext *        eel_gtk_widget_get_pango_ft2_context            (GtkWidget
 gboolean              eel_gtk_tree_view_cell_is_completely_visible    (GtkTreeView          *tree_view,
 								       GtkTreePath          *path,
 								       GtkTreeViewColumn    *column);
+void                  eel_gtk_tree_view_set_activate_on_single_click  (GtkTreeView               *tree_view,
+								       gboolean                   should_activate);
 
 /* GtkViewport */
 gboolean              eel_gtk_viewport_get_visible_rect               (GtkViewport          *viewport, 
